BioSequence

Struct BioSequence 

pub struct BioSequence { /* private fields */ }
Owned biological sequence data with a descriptive kind.

Implementations

Source

impl BioSequence

pub fn new( kind: SequenceKind, text: impl AsRef<str>, ) -> Result<Self, SequenceError>

Creates a biological sequence from non-empty owned text.

Errors

Returns SequenceError::EmptyText when the supplied text is empty.

pub const fn empty(kind: SequenceKind) -> Self

Creates an explicitly empty sequence with the given kind.

pub const fn kind(&self) -> &SequenceKind

Returns the descriptive sequence kind.

pub const fn text(&self) -> &SequenceText

Returns the owned sequence text wrapper.

pub fn len(&self) -> usize

Returns the number of Unicode scalar values in the sequence text.

pub fn sequence_length(&self) -> SequenceLength

Returns the sequence length wrapper.

pub const fn is_empty(&self) -> bool

Returns true when the sequence text is empty.

pub fn as_str(&self) -> &str

Returns the sequence text.